--- title: `nixtlats`:Deep Learning for Time Series Forecasting keywords: fastai sidebar: home_sidebar summary: "[nikstla] (noun, nahuatl) Period of time." description: "[nikstla] (noun, nahuatl) Period of time." nb_path: "nbs/index.ipynb" ---
{% raw %}
{% endraw %}

State-of-the-art time series forecasting for pytorch.

Nixtla is a python library for time series forecasting with deep learning. It provides dataset loading utilities, evaluation functions and pytorch implementations of state of the art deep learning forecasting models.

## Documentation

Here is a link to the documentation.

## Installation

### Stable version

This code is a work in progress, any contributions or issues are welcome on GitHub at: https://github.com/Nixtla/nixtlats.

You can install the released version of `nixtlats` from the Python package index with:

    pip install nixtlats

(installing inside a python virtualenvironment or a conda environment is recommended).

### Development version in development mode

If you want to make some modifications to the code and see the effects in real time (without reinstalling), follow the steps below:

    git clone https://github.com/Nixtla/nixtlats.git
    cd nixtlats
    pip install -e .

## Current available models

- Exponential Smoothing Recurrent Neural Network (ES-RNN): A hybrid model that combines the expressivity of non linear models to capture the trends while it normalizes using a Holt-Winters inspired model for the levels and seasonals. This model is the winner of the M4 forecasting competition.

- Neural Basis Expansion Analysis (N-BEATS): A model from Element-AI (Yoshua Bengio’s lab) that has proven to achieve state of the art performance on benchmark large scale forecasting datasets like Tourism, M3, and M4. The model is fast to train an has an interpretable configuration.

- Neural Basis Expansion Analysis with Exogenous Variables (N-BEATSx): The neural basis expansion with exogenous variables is an extension to the original N-BEATS that allows it to include time dependent covariates.

## License

This project is licensed under the MIT License - see the LICENSE file for details.

## How to contribute

See CONTRIBUTING.md.

## How to cite

If you use `Nixtla` in a scientific publication, we encourage you to add the following references to the related papers:

    @article{nixtla_arxiv,
      author  = {XXXX},
      title   = {{nixtlats: Deep Learning for Time Series Forecasting}},
      journal = {arXiv preprint arXiv:XXX.XXX},
      year    = {2021}
    }